@@ -1,14 +1,17 @@
 #' Create HTML splash pages for packages
 #' @author Dinakar Kulkarni <kulkard2@gene.com>
 #' @importFrom htmlTable htmlTable
-#' @importFrom tools file_path_sans_ext
+#' @importFrom tools file_path_sans_ext file_ext
 #' @importFrom jsonlite toJSON
+#' @importFrom markdown markdownToHTML
 #' @param repo A gRAN repo object
 #' @param splashname Filename for the HTML splash page
 #' @param theme CSS theme. bootstrap, foundation, semanticui or jqueryui
 #' @return None
 #' @export
-pkgHTML <- function(repo, splashname = "index.html", theme = "bootstrap") {
+pkgHTML <- function(repo,
+                    splashname = "index.html",
+                    theme = "bootstrap") {
   logfun(repo)("NA", paste("Creating HTML splash pages for",
                             sum(repo_results(repo)$building), "packages"))
 
@@ -46,17 +49,22 @@ pkgHTML <- function(repo, splashname = "index.html", theme = "bootstrap") {
       if (file.exists(file.path(check_dir, pkg_name, "DESCRIPTION"))) {
         descr_df <- generateDescInfo(file.path(check_dir, pkg_name))
 
+        # Get reverse dependencies
+        revdeps <- reversals(pkg_name)
+
         # Create JSON of the DESCRIPTION file
-        createJSON(repo, pkg_name, descr_df, scm_df, docdir)
+        json_suffix <- paste0("_", descr_df$Version, ".json")
+        createJSON(repo, pkg_name, descr_df, scm_df, docdir, revdeps,
+                   suffix = json_suffix)
 
         # Exclude these fields from the splash page
         descr_df <- descr_df[ , !(names(descr_df) %in%
                                   c("Authors@R", "Collate"))]
         if("URL" %in% colnames(descr_df)) {
-          descr_df$URL <- createURL(descr_df$URL)
+          descr_df$URL <- createHyperlink(descr_df$URL)
         }
         if("BugReports" %in% colnames(descr_df)) {
-          descr_df$BugReports <- createURL(descr_df$BugReports)
+          descr_df$BugReports <- createHyperlink(descr_df$BugReports)
         }
         if("Suggests" %in% colnames(descr_df)) {
           descr_df$Suggests <- extPkgURL(descr_df$Suggests)
@@ -69,22 +77,24 @@ pkgHTML <- function(repo, splashname = "index.html", theme = "bootstrap") {
                         css.cell = ("padding-left: 0.5em; padding-right: 0.5em"),
                         css.class = "table table-striped table-hover",
                         css.table = "margin-left:10px;margin-right:10px;",
-                        align="l", rnames = names(descr_df),
+                        align="l",
+                        rnames = names(descr_df),
                         escape.html = FALSE)
         logfun(repo)("NA", paste("Created DESCRIPTION info for", pkg_name))
       } else {
         desc_header <- ""
         desc_html <- ""
       }
-      # Reverse dependencies
-      revdeps <- reversals(pkg_name)
+
+      # Create HTML for reverse deps
       if (!(is.data.frame(revdeps) && ncol(revdeps)==0)) {
         revdeps_header <- "<br/><h4>Reverse Dependencies</h4><hr>"
         revdeps_html <- htmlTable(t(revdeps),
                         css.cell = ("padding-left: 0.5em; padding-right: 0.5em"),
                         css.class = "table table-striped table-hover",
                         css.table = "margin-left:10px;margin-right:10px;",
-                        align="l", rnames = names(revdeps),
+                        align="l",
+                        rnames = names(revdeps),
                         escape.html = FALSE)
         logfun(repo)("NA", paste("Created revdep info for", pkg_name))
       } else {
@@ -129,13 +139,12 @@ pkgHTML <- function(repo, splashname = "index.html", theme = "bootstrap") {
 
       logfun(repo)("NA", paste("Created installation info for", pkg_name))
 
-      # Copy reference manual, vignettes and NEWS into destination
+      # Copy reference manual, vignettes and NEWS into pkg docs dir
       reference_man <- file.path(check_dir, paste0(pkg_name, '-manual.pdf'))
       if (file.exists(reference_man)) {
         file.copy(reference_man, docdir)
         manref_url <- paste("<p>Reference Manual:",
-                            createURL(file.path("..", "..", "PkgDocumentation",
-                                      pkg_name, paste0(pkg_name, '-manual.pdf')),
+                            createHyperlink(paste0(pkg_name, '-manual.pdf'),
                                       label = paste0(pkg_name, '-manual.pdf')),
                             "</p>")
         doc_header <- "<br/><h4>Package Documentation</h4><hr>"
@@ -146,6 +155,7 @@ pkgHTML <- function(repo, splashname = "index.html", theme = "bootstrap") {
 
       check_docs <- file.path(check_dir, pkg_name, 'doc')
       if (file.exists(check_docs)) {
+
         # Create link for PDF Vignettes files
         rnw_files <- list.files(check_docs, pattern = "\\.Rnw", full.names = TRUE)
         if (length(rnw_files) > 0) {
@@ -153,15 +163,15 @@ pkgHTML <- function(repo, splashname = "index.html", theme = "bootstrap") {
           for (rnw_file in rnw_files) {
             pdf_file <- paste0(file_path_sans_ext(rnw_file), ".pdf")
             file.copy(pdf_file, docdir)
-            vign_url <- createURL(file.path("..", "..", "PkgDocumentation",
-                                  pkg_name, basename(pdf_file)),
-                                  label = basename(pdf_file))
+            vign_url <- createHyperlink(basename(pdf_file),
+                                        label = basename(pdf_file))
             vign_vec <- append(vign_vec, vign_url)
           }
           pdf_vign_header <- paste("<p>PDF Vignettes:", paste(vign_vec,
                                                       collapse = ", "), "</p>")
           logfun(repo)("NA", paste("Created PDF Vignette info for", pkg_name))
         } else pdf_vign_header <- ""
+
         # Create link for HTML Vignettes files
         rmd_files <- list.files(check_docs, pattern = "\\.Rmd", full.names = TRUE)
         if (length(rmd_files) > 0) {
@@ -169,41 +179,114 @@ pkgHTML <- function(repo, splashname = "index.html", theme = "bootstrap") {
           for (rmd_file in rmd_files) {
             html_file <- paste0(file_path_sans_ext(rmd_file), ".html")
             file.copy(html_file, docdir)
-            vign_url2 <- createURL(file.path("..", "..", "PkgDocumentation",
-                                   pkg_name, basename(html_file)),
-                                   label = basename(html_file))
+            vign_url2 <- createHyperlink(basename(html_file),
+                                         label = basename(html_file))
             vign_vec2 <- append(vign_vec2, vign_url2)
           }
           html_vign_header <- paste("<p>HTML Vignettes:", paste(vign_vec2,
                                                       collapse = ", "), "</p>")
           logfun(repo)("NA", paste("Created HTML Vignette info", pkg_name))
         } else html_vign_header <- ""
+
         # Create link for NEWS files
         news_files <- list.files(file.path(check_docs, '..'),
                                   pattern = "NEWS*", full.names = TRUE)
         if (length(news_files) > 0) {
           news_vec <- c()
           for (news_file in news_files) {
-            file.copy(news_file, docdir)
-            news_url <- createURL(file.path("..", "..", "PkgDocumentation",
-                                   pkg_name, basename(news_file)),
-                                   label = basename(news_file))
+            # Convert NEWS.md into HTML
+            if(file_ext(news_file) == "md") {
+              markdownToHTML(file = news_file,
+                             output = file.path(docdir, basename(news_file)))
+            } else {
+              file.copy(news_file, docdir)
+            }
+            news_url <- createHyperlink(basename(news_file),
+                                        label = basename(news_file))
             news_vec <- append(news_vec, news_url)
           }
           news_header <- paste("<p>NEWS files:", paste(news_vec,
                                                       collapse = ", "), "</p>")
           logfun(repo)("NA", paste("Created NEWS info", pkg_name))
         } else news_header <- ""
+
+        # Create link for README files
+        readme_files <- list.files(file.path(check_docs, '..', '..',
+                                             '00_pkg_src', pkg_name),
+                                  pattern = "README*", full.names = TRUE)
+        if (length(readme_files) > 0) {
+          readme_vec <- c()
+          for (readme_file in readme_files) {
+            # Convert README.md into HTML
+            if(file_ext(readme_file) == "md") {
+              markdownToHTML(file = readme_file,
+                             output = file.path(docdir, basename(readme_file)))
+            } else {
+              file.copy(readme_file, docdir)
+            }
+            readme_url <- createHyperlink(basename(readme_file),
+                                          label = basename(readme_file))
+            readme_vec <- append(readme_vec, readme_url)
+          }
+          readme_header <- paste("<p>README files:",
+                                 paste(readme_vec, collapse = ", "), "</p>")
+          logfun(repo)("NA", paste("Created README info", pkg_name))
+        } else readme_header <- ""
+
+        # Create link for package source
+        src_build <- file.path(destination(repo),
+                               paste0(pkg_name, "_", descr_df$Version, ".tar.gz"))
+        src_build_uri <- file.path("..",
+                                   "..",
+                                   "src",
+                                   "contrib",
+                                   basename(src_build))
+        if (file.exists(src_build)) {
+          src_build_url <- paste("<p>Package source:",
+                                 createHyperlink(src_build_uri,
+                                                 label = basename(src_build)),
+                                 "</p>")
+        } else src_build_url <- ""
+
+        # Create link for package archive
+        pkg_archive_dir <- file.path(archivedir(repo), pkg_name)
+        pkg_archive_uri <- file.path("..",
+                                     "..",
+                                     "src",
+                                     "contrib",
+                                     basename(archivedir(repo)),
+                                     basename(pkg_archive_dir))
+        if (file.exists(pkg_archive_dir)) {
+          pkg_archive_url <- paste("<p>Old sources:",
+                                   createHyperlink(pkg_archive_uri,
+                                                   label = paste(pkg_name,
+                                                                 "Archive")),
+                                   "</p>")
+        } else pkg_archive_url <- ""
+
+        # Create link for package metadata JSON
+        pkg_metadata_json <- file.path(docdir, paste0(pkg_name, json_suffix))
+        if (file.exists(pkg_metadata_json)) {
+          pkg_json_url <- paste("<p>View metadata JSON:",
+                                   createHyperlink(basename(pkg_metadata_json)),
+                                "</p>")
+        } else pkg_json_url <- ""
+
       } else {
         pdf_vign_header <- ""
         html_vign_header <- ""
         news_header <- ""
+        readme_header <- ""
+        src_build_url <- ""
+        pkg_archive_url <- ""
+        pkg_json_url <- ""
       }
 
       # Create HTML snippet for documentation, NEWS, vignettes
 
-      doc_content <- paste(manref_url, pdf_vign_header,
-                           html_vign_header, news_header)
+      doc_content <- paste(readme_header, manref_url, pdf_vign_header,
+                           html_vign_header, news_header, src_build_url,
+                           pkg_archive_url, pkg_json_url)
 
       # Construct final HTML
       final_html <- paste0("<html><head>", "<title>", pkg_name, " on GRAN",
@@ -212,6 +295,21 @@ pkgHTML <- function(repo, splashname = "index.html", theme = "bootstrap") {
                           installn, desc_header, desc_html, revdeps_header,
                           revdeps_html, doc_header, doc_content, "</body></html>")
 
+      # Save the previous splash page
+      # If we're doing this, we'll need to do this for the remaining docs also.
+      # CRAN doesn't do this.
+      # Besides, if old sources are available from the archive then
+      # the required docs can be obtained from that.
+      # One could store the docs & sources into a CMS via separate mechanisms.
+      #if (file.exists(file.path(docdir, splashname))) {
+      #  file.rename(from = file.path(docdir, splashname),
+      #              to = file.path(docdir,
+      #                             paste0(pkg_name,
+      #                                    "_",
+      #                                    descr_df$Version,
+      #                                    ".html")))
+      #}
+
       # Create the HTML spash page
       logfun(repo)("NA", paste("Writing final pkg HTML info", pkg_name))
       write(final_html, file = file.path(docdir, splashname))
@@ -219,7 +317,7 @@ pkgHTML <- function(repo, splashname = "index.html", theme = "bootstrap") {
   }
 
   logfun(repo)("NA", paste0("Completed HTML splash page creation for ",
-               length(bres$name), " packages."), type = "both")
+               length(bres$name), " packages."))
   NULL
 }
 
@@ -287,13 +385,13 @@ determinePkgURL <- function(pkg_name) {
   bioc_exp_url <- paste0(bioc_home, "/data/experiment/html/", pkg_name, ".html")
   bioc_ano_url <- paste0(bioc_home, "/data/annotation/html/", pkg_name, ".html")
   if (url.exists(cran_url)) {
-    url <- createURL(cran_url, pkg_name)
+    url <- createHyperlink(cran_url, pkg_name)
   } else if (url.exists(bioc_soft_url)) {
-    url <- createURL(bioc_soft_url, pkg_name)
+    url <- createHyperlink(bioc_soft_url, pkg_name)
   } else if (url.exists(bioc_exp_url)) {
-    url <- createURL(bioc_exp_url, pkg_name)
+    url <- createHyperlink(bioc_exp_url, pkg_name)
   } else if (url.exists(bioc_ano_url)) {
-    url <- createURL(bioc_ano_url, pkg_name)
+    url <- createHyperlink(bioc_ano_url, pkg_name)
   } else {
     url <- pkg_name
   }
@@ -365,7 +463,7 @@ string2list <- function(string, separator = ",") {
 #' @param string URL string
 #' @param label Label for href
 #' @return href tag
-createURL <- function(string, label = "") {
+createHyperlink <- function(string, label = "") {
   if (label == "" || is.null(label)) {
     label <- gsub("(/+)", "\\1&#8203;", string)
   }
@@ -438,41 +536,3 @@ buildBadge <- function(status, pkg_name) {
         label, "\">", status, "</span></a>")
 }
 
-#' Create JSON representation of package information
-#' @author Dinakar Kulkarni <kulkard2@gene.com>
-#' @importFrom jsonlite toJSON
-#' @param repo A GRAN repo object
-#' @param pkg_name Name of the GRAN package
-#' @param descr_df data.frame representation of DESCRIPTION file
-#' @param scm_df data.frame representation of GRAN manifest object
-#' @param docdir Directory where the JSON doc will be written
-#' @param suffix Suffix for the JSON file
-#' @return None. Write JSON file to disk
-#' @seealso \code{\link{manifest_df}} for generating scm_df and
-#'    \code{\link{generateDescInfo}} for generating descr_df.
-createJSON <- function(repo, pkg_name, descr_df, scm_df, docdir,
-                       suffix = paste0("_", descr_df$Version, "-desc.json")) {
-  reponame <- paste0("GRAN", repo_name(repo))
-  descr_df$id <- encode_string(paste0(reponame, descr_df$Package))
-  descr_df$GranRepo <- reponame
-
-  # Get SCM info:
-  scm_info <- scm_df[scm_df$name == pkg_name, ]
-  descr_df$scm_url <- scm_info$url
-  descr_df$scm_type <- scm_info$type
-  descr_df$scm_branch <- scm_info$branch
-  descr_df$scm_subdir <- scm_info$subdir
-  descr_df$RVersion <- R.version$version.string
-  #descr_df$BiocVersion <- BiocInstaller::biocVersion()
-
-  # Get documentation URL locations:
-  doc_url <- paste0(repo_url(repo), "/PkgDocumentation/", pkg_name)
-  descr_df$pkgdocs_url <- doc_url
-
-  # Convert to JSON
-  desc_json <- toJSON(descr_df, pretty = TRUE)
-  json_outfile <- file.path(docdir, paste0(pkg_name, suffix))
-
-  # Write JSON
-  write(desc_json, json_outfile)
-}
